# popsynth

A simple OO population synthesis code designed for testing population inference in Stan. It also makes a lot of pretty pictures.

![alt text](https://raw.githubusercontent.com/grburgess/popsynth/master/pop.png)
